@@ -266,7 +266,7 @@ class MultiBot(Generic[T]):
             'original_event': event
         })
         message.resolve()
-        message.save(pull_exclude=('author', 'button_text', 'chat', 'mentions', 'replied_message'), pull_database_priority=True)
+        message.save(pull_overwrite_fields='config')
 
         return message
 
@@ -312,16 +312,16 @@ class MultiBot(Generic[T]):
     def _parse_callbacks(
         self,
         text: str,
-        ratio_reward_exponent: float = 7,
-        keywords_lenght_penalty: float = 0.05,
-        minimum_ratio_to_match: float = 21
+        ratio_reward_exponent: float = constants.RATIO_REWARD_EXPONENT,
+        keywords_lenght_penalty: float = constants.KEYWORDS_LENGHT_PENALTY,
+        minimum_ratio_to_match: float = constants.MINIMUM_RATIO_TO_MATCH
     ) -> OrderedSet[RegisteredCallback]:
         text = text.lower()
         text = flanautils.remove_accents(text)
         text = flanautils.translate(text, {'?': ' ', '¿': ' ', '!': ' ', '¡': ' ', '_': ' ', 'auto': 'auto '})
         text = flanautils.translate(text, {'auto': 'automatico', 'matico': None, 'matic': None})
         original_text_words = OrderedSet(text.split())
-        text_words = original_text_words - flanautils.CommonWords.words
+        text_words = original_text_words - flanautils.CommonWords.all_words
 
         matched_callbacks: set[RatioMatch[RegisteredCallback]] = set()
         always_callbacks: set[RegisteredCallback] = set()
@@ -420,7 +420,7 @@ class MultiBot(Generic[T]):
     @ignore_self_message
     async def _on_new_message_raw(self, message: Message):
         try:
-            registered_callbacks = self._parse_callbacks(message.text, constants.RATIO_REWARD_EXPONENT, constants.KEYWORDS_LENGHT_PENALTY, constants.MINIMUM_RATIO_TO_MATCH)
+            registered_callbacks = self._parse_callbacks(message.text)
         except AmbiguityError as e:
             await self._manage_exceptions(e, message)
         else:
@@ -450,45 +450,10 @@ class MultiBot(Generic[T]):
     async def delete_message(self, message_to_delete: int | str | Message, chat: int | str | Chat | Message = None):
         pass
 
-    @overload
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_chat(self, chat_id: int) -> Chat | None:
-        pass
-
-    @overload
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_chat(self, chat_name: str) -> Chat | None:
-        pass
-
-    @overload
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_chat(self, chat: Chat) -> Chat | None:
-        pass
-
-    @overload
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_chat(self, message: Message) -> Chat | None:
-        pass
-
     @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
     async def get_chat(self, chat: int | str | Chat | Message) -> Chat | None:
         pass
 
-    @overload
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_user(self, user_id: int, group_id: int | str = None) -> User | None:
-        pass
-
-    @overload
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_user(self, user_name: str, group_id: int | str = None) -> User | None:
-        pass
-
-    @overload
-    @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
-    async def get_user(self, user: User, group_id: int | str = None) -> User | None:
-        pass
-
     @return_if_first_empty(exclude_self_types='MultiBot', globals_=globals())
     async def get_user(self, user: int | str | User, group_id: int | str = None) -> User | None:
         pass
@@ -553,5 +518,5 @@ class MultiBot(Generic[T]):
     async def typing_delay(self, message: Message):
         pass
 
-    async def unban(self, user: int | str | User, chat: int | str | Chat, message: Message = None):
+    async def unban(self, user: int | str | User, chat: int | str | Chat | Message):
         pass
